@@ -18,6 +18,7 @@ import functools
 import re
 from typing import (
     Dict,
+    Mapping,
     Optional,
     AsyncIterable,
     Awaitable,
@@ -233,9 +234,9 @@ class FirestoreAsyncClient:
 
             from google.cloud import firestore_v1
 
-            def sample_get_document():
+            async def sample_get_document():
                 # Create a client
-                client = firestore_v1.FirestoreClient()
+                client = firestore_v1.FirestoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = firestore_v1.GetDocumentRequest(
@@ -244,7 +245,7 @@ class FirestoreAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_document(request=request)
+                response = await client.get_document(request=request)
 
                 # Handle the response
                 print(response)
@@ -295,7 +296,12 @@ class FirestoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -314,9 +320,9 @@ class FirestoreAsyncClient:
 
             from google.cloud import firestore_v1
 
-            def sample_list_documents():
+            async def sample_list_documents():
                 # Create a client
-                client = firestore_v1.FirestoreClient()
+                client = firestore_v1.FirestoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = firestore_v1.ListDocumentsRequest(
@@ -329,7 +335,7 @@ class FirestoreAsyncClient:
                 page_result = client.list_documents(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -377,16 +383,29 @@ class FirestoreAsyncClient:
         # Certain fields should be provided within the metadata header;
         # add these here.
         metadata = tuple(metadata) + (
-            gapic_v1.routing_header.to_grpc_metadata((("parent", request.parent),)),
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("parent", request.parent),
+                    ("collection_id", request.collection_id),
+                )
+            ),
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListDocumentsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -408,16 +427,16 @@ class FirestoreAsyncClient:
 
             from google.cloud import firestore_v1
 
-            def sample_update_document():
+            async def sample_update_document():
                 # Create a client
-                client = firestore_v1.FirestoreClient()
+                client = firestore_v1.FirestoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = firestore_v1.UpdateDocumentRequest(
                 )
 
                 # Make the request
-                response = client.update_document(request=request)
+                response = await client.update_document(request=request)
 
                 # Handle the response
                 print(response)
@@ -506,7 +525,12 @@ class FirestoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -526,9 +550,9 @@ class FirestoreAsyncClient:
 
             from google.cloud import firestore_v1
 
-            def sample_delete_document():
+            async def sample_delete_document():
                 # Create a client
-                client = firestore_v1.FirestoreClient()
+                client = firestore_v1.FirestoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = firestore_v1.DeleteDocumentRequest(
@@ -536,7 +560,7 @@ class FirestoreAsyncClient:
                 )
 
                 # Make the request
-                client.delete_document(request=request)
+                await client.delete_document(request=request)
 
         Args:
             request (Union[google.cloud.firestore_v1.types.DeleteDocumentRequest, dict]):
@@ -601,7 +625,10 @@ class FirestoreAsyncClient:
 
         # Send the request.
         await rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
     def batch_get_documents(
@@ -616,14 +643,13 @@ class FirestoreAsyncClient:
         Documents returned by this method are not guaranteed to
         be returned in the same order that they were requested.
 
-
         .. code-block:: python
 
             from google.cloud import firestore_v1
 
-            def sample_batch_get_documents():
+            async def sample_batch_get_documents():
                 # Create a client
-                client = firestore_v1.FirestoreClient()
+                client = firestore_v1.FirestoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = firestore_v1.BatchGetDocumentsRequest(
@@ -632,10 +658,10 @@ class FirestoreAsyncClient:
                 )
 
                 # Make the request
-                stream = client.batch_get_documents(request=request)
+                stream = await client.batch_get_documents(request=request)
 
                 # Handle the response
-                for response in stream:
+                async for response in stream:
                     print(response)
 
         Args:
@@ -684,7 +710,12 @@ class FirestoreAsyncClient:
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -704,9 +735,9 @@ class FirestoreAsyncClient:
 
             from google.cloud import firestore_v1
 
-            def sample_begin_transaction():
+            async def sample_begin_transaction():
                 # Create a client
-                client = firestore_v1.FirestoreClient()
+                client = firestore_v1.FirestoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = firestore_v1.BeginTransactionRequest(
@@ -714,7 +745,7 @@ class FirestoreAsyncClient:
                 )
 
                 # Make the request
-                response = client.begin_transaction(request=request)
+                response = await client.begin_transaction(request=request)
 
                 # Handle the response
                 print(response)
@@ -786,7 +817,12 @@ class FirestoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -804,14 +840,13 @@ class FirestoreAsyncClient:
         r"""Commits a transaction, while optionally updating
         documents.
 
-
         .. code-block:: python
 
             from google.cloud import firestore_v1
 
-            def sample_commit():
+            async def sample_commit():
                 # Create a client
-                client = firestore_v1.FirestoreClient()
+                client = firestore_v1.FirestoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = firestore_v1.CommitRequest(
@@ -819,7 +854,7 @@ class FirestoreAsyncClient:
                 )
 
                 # Make the request
-                response = client.commit(request=request)
+                response = await client.commit(request=request)
 
                 # Handle the response
                 print(response)
@@ -898,7 +933,12 @@ class FirestoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -919,9 +959,9 @@ class FirestoreAsyncClient:
 
             from google.cloud import firestore_v1
 
-            def sample_rollback():
+            async def sample_rollback():
                 # Create a client
-                client = firestore_v1.FirestoreClient()
+                client = firestore_v1.FirestoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = firestore_v1.RollbackRequest(
@@ -930,7 +970,7 @@ class FirestoreAsyncClient:
                 )
 
                 # Make the request
-                client.rollback(request=request)
+                await client.rollback(request=request)
 
         Args:
             request (Union[google.cloud.firestore_v1.types.RollbackRequest, dict]):
@@ -1003,7 +1043,10 @@ class FirestoreAsyncClient:
 
         # Send the request.
         await rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
     def run_query(
@@ -1020,9 +1063,9 @@ class FirestoreAsyncClient:
 
             from google.cloud import firestore_v1
 
-            def sample_run_query():
+            async def sample_run_query():
                 # Create a client
-                client = firestore_v1.FirestoreClient()
+                client = firestore_v1.FirestoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = firestore_v1.RunQueryRequest(
@@ -1031,10 +1074,10 @@ class FirestoreAsyncClient:
                 )
 
                 # Make the request
-                stream = client.run_query(request=request)
+                stream = await client.run_query(request=request)
 
                 # Handle the response
-                for response in stream:
+                async for response in stream:
                     print(response)
 
         Args:
@@ -1083,7 +1126,12 @@ class FirestoreAsyncClient:
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1102,14 +1150,13 @@ class FirestoreAsyncClient:
         used by RunQuery as starting/end points for the query
         results.
 
-
         .. code-block:: python
 
             from google.cloud import firestore_v1
 
-            def sample_partition_query():
+            async def sample_partition_query():
                 # Create a client
-                client = firestore_v1.FirestoreClient()
+                client = firestore_v1.FirestoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = firestore_v1.PartitionQueryRequest(
@@ -1120,7 +1167,7 @@ class FirestoreAsyncClient:
                 page_result = client.partition_query(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -1172,12 +1219,20 @@ class FirestoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.PartitionQueryAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1194,14 +1249,13 @@ class FirestoreAsyncClient:
         r"""Streams batches of document updates and deletes, in
         order.
 
-
         .. code-block:: python
 
             from google.cloud import firestore_v1
 
-            def sample_write():
+            async def sample_write():
                 # Create a client
-                client = firestore_v1.FirestoreClient()
+                client = firestore_v1.FirestoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = firestore_v1.WriteRequest(
@@ -1219,10 +1273,10 @@ class FirestoreAsyncClient:
                         yield request
 
                 # Make the request
-                stream = client.write(requests=request_generator())
+                stream = await client.write(requests=request_generator())
 
                 # Handle the response
-                for response in stream:
+                async for response in stream:
                     print(response)
 
         Args:
@@ -1265,7 +1319,12 @@ class FirestoreAsyncClient:
         metadata = tuple(metadata) + (gapic_v1.routing_header.to_grpc_metadata(()),)
 
         # Send the request.
-        response = rpc(requests, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            requests,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1284,9 +1343,9 @@ class FirestoreAsyncClient:
 
             from google.cloud import firestore_v1
 
-            def sample_listen():
+            async def sample_listen():
                 # Create a client
-                client = firestore_v1.FirestoreClient()
+                client = firestore_v1.FirestoreAsyncClient()
 
                 # Initialize request argument(s)
                 add_target = firestore_v1.Target()
@@ -1308,10 +1367,10 @@ class FirestoreAsyncClient:
                         yield request
 
                 # Make the request
-                stream = client.listen(requests=request_generator())
+                stream = await client.listen(requests=request_generator())
 
                 # Handle the response
-                for response in stream:
+                async for response in stream:
                     print(response)
 
         Args:
@@ -1356,7 +1415,12 @@ class FirestoreAsyncClient:
         metadata = tuple(metadata) + (gapic_v1.routing_header.to_grpc_metadata(()),)
 
         # Send the request.
-        response = rpc(requests, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            requests,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1376,9 +1440,9 @@ class FirestoreAsyncClient:
 
             from google.cloud import firestore_v1
 
-            def sample_list_collection_ids():
+            async def sample_list_collection_ids():
                 # Create a client
-                client = firestore_v1.FirestoreClient()
+                client = firestore_v1.FirestoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = firestore_v1.ListCollectionIdsRequest(
@@ -1389,7 +1453,7 @@ class FirestoreAsyncClient:
                 page_result = client.list_collection_ids(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -1464,12 +1528,20 @@ class FirestoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListCollectionIdsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1495,14 +1567,13 @@ class FirestoreAsyncClient:
         If you require an atomically applied set of writes, use
         [Commit][google.firestore.v1.Firestore.Commit] instead.
 
-
         .. code-block:: python
 
             from google.cloud import firestore_v1
 
-            def sample_batch_write():
+            async def sample_batch_write():
                 # Create a client
-                client = firestore_v1.FirestoreClient()
+                client = firestore_v1.FirestoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = firestore_v1.BatchWriteRequest(
@@ -1510,7 +1581,7 @@ class FirestoreAsyncClient:
                 )
 
                 # Make the request
-                response = client.batch_write(request=request)
+                response = await client.batch_write(request=request)
 
                 # Handle the response
                 print(response)
@@ -1560,7 +1631,12 @@ class FirestoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1579,9 +1655,9 @@ class FirestoreAsyncClient:
 
             from google.cloud import firestore_v1
 
-            def sample_create_document():
+            async def sample_create_document():
                 # Create a client
-                client = firestore_v1.FirestoreClient()
+                client = firestore_v1.FirestoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = firestore_v1.CreateDocumentRequest(
@@ -1590,7 +1666,7 @@ class FirestoreAsyncClient:
                 )
 
                 # Make the request
-                response = client.create_document(request=request)
+                response = await client.create_document(request=request)
 
                 # Handle the response
                 print(response)
@@ -1635,11 +1711,21 @@ class FirestoreAsyncClient:
         # Certain fields should be provided within the metadata header;
         # add these here.
         metadata = tuple(metadata) + (
-            gapic_v1.routing_header.to_grpc_metadata((("parent", request.parent),)),
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("parent", request.parent),
+                    ("collection_id", request.collection_id),
+                )
+            ),
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1653,7 +1739,9 @@ class FirestoreAsyncClient:
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-firestore",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-firestore",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
