@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,11 +16,10 @@
 import warnings
 from typing import Awaitable, Callable, Dict, Optional, Sequence, Tuple, Union
 
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import grpc_helpers_async  # type: ignore
+from google.api_core import gapic_v1
+from google.api_core import grpc_helpers_async
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-import packaging.version
 
 import grpc  # type: ignore
 from grpc.experimental import aio  # type: ignore
@@ -37,13 +36,13 @@ class FirestoreGrpcAsyncIOTransport(FirestoreTransport):
     """gRPC AsyncIO backend transport for Firestore.
 
     The Cloud Firestore service.
-    Cloud Firestore is a fast, fully managed, serverless, cloud-
-    native NoSQL document database that simplifies storing, syncing,
-    and querying data for your mobile, web, and IoT apps at global
-    scale. Its client libraries provide live synchronization and
-    offline support, while its security features and integrations
-    with Firebase and Google Cloud Platform (GCP) accelerate
-    building truly serverless apps.
+    Cloud Firestore is a fast, fully managed, serverless,
+    cloud-native NoSQL document database that simplifies storing,
+    syncing, and querying data for your mobile, web, and IoT apps at
+    global scale. Its client libraries provide live synchronization
+    and offline support, while its security features and
+    integrations with Firebase and Google Cloud Platform (GCP)
+    accelerate building truly serverless apps.
 
     This class defines the same methods as the primary client, so the
     primary client can load the underlying transport implementation
@@ -137,16 +136,16 @@ class FirestoreGrpcAsyncIOTransport(FirestoreTransport):
             api_mtls_endpoint (Optional[str]): Deprecated. The mutual TLS endpoint.
                 If provided, it overrides the ``host`` argument and tries to create
                 a mutual TLS channel with client SSL credentials from
-                ``client_cert_source`` or applicatin default SSL credentials.
+                ``client_cert_source`` or application default SSL credentials.
             client_cert_source (Optional[Callable[[], Tuple[bytes, bytes]]]):
                 Deprecated. A callback to provide client SSL certificate bytes and
                 private key bytes, both in PEM format. It is ignored if
                 ``api_mtls_endpoint`` is None.
             ssl_channel_credentials (grpc.ChannelCredentials): SSL credentials
-                for grpc channel. It is ignored if ``channel`` is provided.
+                for the grpc channel. It is ignored if ``channel`` is provided.
             client_cert_source_for_mtls (Optional[Callable[[], Tuple[bytes, bytes]]]):
                 A callback to provide client certificate bytes and private key bytes,
-                both in PEM format. It is used to configure mutual TLS channel. It is
+                both in PEM format. It is used to configure a mutual TLS channel. It is
                 ignored if ``channel`` or ``ssl_channel_credentials`` is provided.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
@@ -214,8 +213,11 @@ class FirestoreGrpcAsyncIOTransport(FirestoreTransport):
         if not self._grpc_channel:
             self._grpc_channel = type(self).create_channel(
                 self._host,
+                # use the credentials which are saved
                 credentials=self._credentials,
-                credentials_file=credentials_file,
+                # Set ``credentials_file`` to ``None`` here as
+                # the credentials that we saved earlier should be used.
+                credentials_file=None,
                 scopes=self._scopes,
                 ssl_credentials=self._ssl_channel_credentials,
                 quota_project_id=quota_project_id,
@@ -661,5 +663,8 @@ class FirestoreGrpcAsyncIOTransport(FirestoreTransport):
             )
         return self._stubs["create_document"]
 
+    def close(self):
+        return self.grpc_channel.close()
+
 
 __all__ = ("FirestoreGrpcAsyncIOTransport",)
